@@ -3,12 +3,7 @@ import unittest
 import config
 from blazewebtestapp.applications import make_wsgi
 from werkzeug import Client, BaseResponse
-
-#########################################################################
-#NOTE: TESTS WILL FAIL UNTIL BUG IN WERKZUEG IS PATCHED
-#http://dev.pocoo.org/projects/werkzeug/ticket/383
-#########################################################################
-
+from blazeweb.testing import TestApp
 
 class TestSession(unittest.TestCase):
 
@@ -31,3 +26,18 @@ class TestSession(unittest.TestCase):
 
         self.assertEqual(r.status, '200 OK')
         self.assertEqual(r.data, 'bar')
+
+    def test_session_regen_id(self):
+        ta = TestApp(self.app)
+
+        r = ta.get('/sessiontests/setfoo', status=200)
+        assert r.session['foo'] == 'bar'
+        sid = r.session.id
+        assert sid in r.headers['Set-Cookie']
+
+        r = ta.get('/sessiontests/regenid', status=200)
+        assert r.session.id != sid
+        assert r.session.id in r.headers['Set-Cookie']
+
+        r = ta.get('/sessiontests/getfoo', status=200)
+        assert r.body == 'bar'
